==> eyepop-1.5.3-py3-none-any.whl: eyepop/worker/worker_syncify.py <==
import logging
import typing

from eyepop.syncify import run_coro_thread_save, SyncEndpoint
from eyepop.worker.worker_jobs import WorkerJob
from eyepop.worker.worker_types import Pop

if typing.TYPE_CHECKING:
    from eyepop.worker.worker_endpoint import WorkerEndpoint

log = logging.getLogger(__name__)


class SyncWorkerJob:
    def __init__(self, job: WorkerJob, event_loop):
        self.job = job
        self.event_loop = event_loop

    def predict(self) -> dict:
        prediction = run_coro_thread_save(self.event_loop, self.job.predict())
        return prediction

    def cancel(self):
        run_coro_thread_save(self.event_loop, self.job.cancel())


class SyncWorkerEndpoint(SyncEndpoint):
    def __init__(self, endpoint: "WorkerEndpoint"):
        super().__init__(endpoint)

    def upload(self, file_path: str, params: dict | None = None,
               on_ready: typing.Callable[[WorkerJob], None] | None = None) -> SyncWorkerJob:
        if on_ready is not None:
            raise TypeError(
                "'on_ready' callback not supported for sync endpoints. "
                "Use 'EyePopSdk.workerEndpoint(is_async=True)` to create an async endpoint with callback support")
        job = run_coro_thread_save(self.event_loop, self.endpoint.upload(file_path, params, None))
        return SyncWorkerJob(job, self.event_loop)

    def upload_stream(self, stream: typing.BinaryIO, mime_type: str, params: dict | None = None,
                      on_ready: typing.Callable[[WorkerJob], None] | None = None) -> SyncWorkerJob:
        if on_ready is not None:
            raise TypeError(
                "'on_ready' callback not supported for sync endpoints. "
                "Use 'EyePopSdk.workerEndpoint(is_async=True)` to create an async endpoint with callback support")
        job = run_coro_thread_save(self.event_loop, self.endpoint.upload_stream(stream, mime_type, params, None))
        return SyncWorkerJob(job, self.event_loop)

    def load_from(self, location: str, params: dict | None = None,
                  on_ready: typing.Callable[[WorkerJob], None] | None = None) -> SyncWorkerJob:
        if on_ready is not None:
            raise TypeError(
                "'on_ready' callback not supported for sync endpoints. "
                "Use 'EyePopSdk.workerEndpoint(is_async=True)` to create an async endpoint with callback support")
        job = run_coro_thread_save(self.event_loop, self.endpoint.load_from(location, params, None))
        return SyncWorkerJob(job, self.event_loop)

    def get_pop(self) -> Pop | None:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_pop())

    def set_pop(self, pop: Pop) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_pop(pop))

    def get_pop_comp(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_pop_comp())

    def set_pop_comp(self, popComp: str, model_refs: list[dict] = []) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_pop_comp(popComp, model_refs))

    def get_post_transform(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_post_transform())

    def set_post_transform(self, transform: str) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_post_transform(transform))

    '''
    Start Block
    Below methods are not meant for the end user to use directly. They are used by the SDK internally.
    '''

    def list_models(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.list_models())

    def get_manifest(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_manifest())

    def set_manifest(self, manifest: dict) -> None:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_manifest(manifest))

    def load_model(self, model: dict, override: bool = False) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.load_model(model, override))

    def unload_model(self, model_id: str) -> None:
        return run_coro_thread_save(self.event_loop, self.endpoint.unload_model(model_id))

    '''
    End Block
    '''

==> eyepop-1.14.1-py3-none-any.whl: eyepop/worker/worker_syncify.py <==
import logging
import typing

from eyepop.syncify import run_coro_thread_save, SyncEndpoint
from eyepop.worker.worker_jobs import WorkerJob
from eyepop.worker.worker_types import Pop, VideoMode, ComponentParams

if typing.TYPE_CHECKING:
    from eyepop.worker.worker_endpoint import WorkerEndpoint

log = logging.getLogger(__name__)


class SyncWorkerJob:
    def __init__(self, job: WorkerJob, event_loop):
        self.job = job
        self.event_loop = event_loop

    def predict(self) -> dict:
        prediction = run_coro_thread_save(self.event_loop, self.job.predict())
        return prediction

    def cancel(self):
        run_coro_thread_save(self.event_loop, self.job.cancel())


class SyncWorkerEndpoint(SyncEndpoint):
    def __init__(self, endpoint: "WorkerEndpoint"):
        super().__init__(endpoint)

    def upload(
            self,
            location: str,
            video_mode: VideoMode | None = None,
            params: list[ComponentParams] | None = None,
            on_ready: typing.Callable[[WorkerJob], None] | None = None
    ) -> SyncWorkerJob:
        if on_ready is not None:
            raise TypeError(
                "'on_ready' callback not supported for sync endpoints. "
                "Use 'EyePopSdk.workerEndpoint(is_async=True)` to create an async endpoint with callback support")
        job = run_coro_thread_save(self.event_loop, self.endpoint.upload(
            location=location, video_mode=video_mode, params=params, on_ready=None))
        return SyncWorkerJob(job, self.event_loop)

    def upload_stream(
            self,
            stream: typing.BinaryIO,
            mime_type: str,
            video_mode: VideoMode | None = None,
            params: list[ComponentParams] | None = None,
            on_ready: typing.Callable[[WorkerJob], None] | None = None
    ) -> SyncWorkerJob:
        if on_ready is not None:
            raise TypeError(
                "'on_ready' callback not supported for sync endpoints. "
                "Use 'EyePopSdk.workerEndpoint(is_async=True)` to create an async endpoint with callback support")
        job = run_coro_thread_save(self.event_loop, self.endpoint.upload_stream(
            stream=stream, mime_type=mime_type, video_mode=video_mode, params=params, on_ready=None
        ))
        return SyncWorkerJob(job, self.event_loop)

    def load_from(
            self,
            location: str,
            params: list[ComponentParams] | None = None,
            on_ready: typing.Callable[[WorkerJob], None] | None = None
    ) -> SyncWorkerJob:
        if on_ready is not None:
            raise TypeError(
                "'on_ready' callback not supported for sync endpoints. "
                "Use 'EyePopSdk.workerEndpoint(is_async=True)` to create an async endpoint with callback support")
        job = run_coro_thread_save(self.event_loop, self.endpoint.load_from(
            location=location, params=params, on_ready=None))
        return SyncWorkerJob(job, self.event_loop)

    def get_pop(self) -> Pop | None:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_pop())

    def set_pop(self, pop: Pop) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_pop(pop))

    def get_pop_comp(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_pop_comp())

    def set_pop_comp(self, popComp: str, model_refs: list[dict] = []) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_pop_comp(popComp, model_refs))

    def get_post_transform(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_post_transform())

    def set_post_transform(self, transform: str) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_post_transform(transform))

    '''
    Start Block
    Below methods are not meant for the end user to use directly. They are used by the SDK internally.
    '''

    def list_models(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.list_models())

    def get_manifest(self) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.get_manifest())

    def set_manifest(self, manifest: dict) -> None:
        return run_coro_thread_save(self.event_loop, self.endpoint.set_manifest(manifest))

    def load_model(self, model: dict, override: bool = False) -> dict:
        return run_coro_thread_save(self.event_loop, self.endpoint.load_model(model, override))

    def unload_model(self, model_id: str) -> None:
        return run_coro_thread_save(self.event_loop, self.endpoint.unload_model(model_id))

    '''
    End Block
    '''
